==> nivo-0.6.0.tgz: package/es/components/charts/bubble/Bubble.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

/*
 * This file is part of the nivo project.
 *
 * Copyright 2016-present, Raphaël Benitte.
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
import React, { Component } from 'react';
import _ from 'lodash-es';
import { convertLabel } from '../../../lib/propertiesConverters';
import { bubblePropTypes, bubbleDefaultProps } from './BubbleProps';
import BubblePlaceholders from './BubblePlaceholders';
import { getColorGenerator } from '../../../ColorUtils';

var createNodes = function createNodes(_ref) {
    var borderWidth = _ref.borderWidth,
        borderColor = _ref.borderColor,
        enableLabel = _ref.enableLabel,
        _label = _ref.label,
        labelFormat = _ref.labelFormat,
        labelSkipRadius = _ref.labelSkipRadius,
        labelTextColor = _ref.labelTextColor,
        labelTextDY = _ref.labelTextDY;

    var label = convertLabel(_label, labelFormat);
    var borderColorFn = getColorGenerator(borderColor);
    var textColorFn = getColorGenerator(labelTextColor);

    return function (nodes) {
        var renderedNodes = [];

        nodes.filter(function (node) {
            return node.style.r > 0;
        }).forEach(function (node) {
            renderedNodes.push(React.createElement('circle', {
                key: node.key + '.circle',
                r: node.style.r,
                className: 'nivo_bubble_node',
                transform: 'translate(' + node.style.x + ',' + node.style.y + ')',
                style: {
                    fill: node.style.color,
                    stroke: borderColorFn(node.style),
                    strokeWidth: borderWidth
                }
            }));
        });

        if (enableLabel === true) {
            nodes.filter(function (node) {
                return node.data.height === 0 && (labelSkipRadius === 0 || node.data.r >= labelSkipRadius);
            }).forEach(function (node) {
                renderedNodes.push(React.createElement(
                    'text',
                    {
                        key: node.key + '.text',
                        className: 'nivo_bubble_legend',
                        transform: 'translate(' + node.style.x + ',' + node.style.y + ')',
                        textAnchor: 'middle',
                        dy: labelTextDY,
                        style: {
                            fill: textColorFn(node.style)
                        }
                    },
                    label(node.data.data)
                ));
            });
        }

        return renderedNodes;
    };
};

var Bubble = function (_Component) {
    _inherits(Bubble, _Component);

    function Bubble() {
        _classCallCheck(this, Bubble);

        return _possibleConstructorReturn(this, _Component.apply(this, arguments));
    }

    Bubble.prototype.render = function render() {
        return React.createElement(
            BubblePlaceholders,
            _extends({}, this.props, { namespace: 'svg' }),
            createNodes(this.props)
        );
    };

    return Bubble;
}(Component);

Bubble.propTypes = _.omit(bubblePropTypes, ['children', 'namespace', 'transitionDuration', 'transitionEasing']);
Bubble.defaultProps = _.omit(bubbleDefaultProps, ['namespace', 'transitionDuration', 'transitionEasing']);
export default Bubble;

==> nivo-0.7.0.tgz: package/es/components/charts/bubble/Bubble.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

/*
 * This file is part of the nivo project.
 *
 * Copyright 2016-present, Raphaël Benitte.
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
import React, { Component } from 'react';
import _ from 'lodash-es';
import { convertLabel } from '../../../lib/propertiesConverters';
import { bubblePropTypes, bubbleDefaultProps } from './BubbleProps';
import BubblePlaceholders from './BubblePlaceholders';
import { getColorGenerator } from '../../../lib/colorUtils';

var createNodes = function createNodes(_ref) {
    var borderWidth = _ref.borderWidth,
        borderColor = _ref.borderColor,
        enableLabel = _ref.enableLabel,
        _label = _ref.label,
        labelFormat = _ref.labelFormat,
        labelSkipRadius = _ref.labelSkipRadius,
        labelTextColor = _ref.labelTextColor,
        labelTextDY = _ref.labelTextDY;

    var label = convertLabel(_label, labelFormat);
    var borderColorFn = getColorGenerator(borderColor);
    var textColorFn = getColorGenerator(labelTextColor);

    return function (nodes) {
        var renderedNodes = [];

        nodes.filter(function (node) {
            return node.style.r > 0;
        }).forEach(function (node) {
            renderedNodes.push(React.createElement('circle', {
                key: node.key + '.circle',
                r: node.style.r,
                className: 'nivo_bubble_node',
                transform: 'translate(' + node.style.x + ',' + node.style.y + ')',
                style: {
                    fill: node.style.color,
                    stroke: borderColorFn(node.style),
                    strokeWidth: borderWidth
                }
            }));
        });

        if (enableLabel === true) {
            nodes.filter(function (node) {
                return node.data.height === 0 && (labelSkipRadius === 0 || node.data.r >= labelSkipRadius);
            }).forEach(function (node) {
                renderedNodes.push(React.createElement(
                    'text',
                    {
                        key: node.key + '.text',
                        className: 'nivo_bubble_legend',
                        transform: 'translate(' + node.style.x + ',' + node.style.y + ')',
                        textAnchor: 'middle',
                        dy: labelTextDY,
                        style: {
                            fill: textColorFn(node.style)
                        }
                    },
                    label(node.data.data)
                ));
            });
        }

        return renderedNodes;
    };
};

var Bubble = function (_Component) {
    _inherits(Bubble, _Component);

    function Bubble() {
        _classCallCheck(this, Bubble);

        return _possibleConstructorReturn(this, _Component.apply(this, arguments));
    }

    Bubble.prototype.render = function render() {
        return React.createElement(
            BubblePlaceholders,
            _extends({}, this.props, { namespace: 'svg' }),
            createNodes(this.props)
        );
    };

    return Bubble;
}(Component);

Bubble.propTypes = _.omit(bubblePropTypes, ['children', 'namespace', 'transitionDuration', 'transitionEasing']);
Bubble.defaultProps = _.omit(bubbleDefaultProps, ['namespace', 'transitionDuration', 'transitionEasing']);
export default Bubble;
